import os
import subprocess
import datetime
import numpy as np
import matplotlib.pyplot as plt


def run_and_time(cmd_pcb, cmd_frep, cwd, dpi):
    t1 = datetime.datetime.now()
    ps = subprocess.Popen(cmd_pcb, stdout=subprocess.PIPE, cwd=cwd)
    subprocess.check_output(cmd_frep.format(dpi), cwd=cwd, stdin=ps.stdout)
    t2 = datetime.datetime.now()
    return (t2-t1).total_seconds()


def main():
    cmd_pcb1 = "python pcb.py"
    cmd_pcb2 = "python test.py"
    cmd_frep1 = "python frep.py {}"
    cmd_frep2 = "python frep_gpu.py {}"
    cwd1 = "pcb_legacy"
    cwd2 = "pcb_opengl"

    dpi_list = np.array([50, 100, 200, 300, 400, 500, 650, 800, 1000], np.int32)
    n = len(dpi_list)
    n_mean = 4
    dt_list1 = np.zeros((n,))
    dt_list2 = np.zeros((n,))

    for i in range(n):
        dpi = dpi_list[i]
        dt_all1 = []
        dt_all2 = []
        for j in range(n_mean):
            dt1 = run_and_time(cmd_pcb1, cmd_frep1, cwd1, dpi)
            dt2 = run_and_time(cmd_pcb2, cmd_frep2, cwd2, dpi)
            dt_all1.append(dt1)
            dt_all2.append(dt2)
        dt_list1[i] = np.mean(dt_all1)
        dt_list2[i] = np.mean(dt_all2)
        print("{} {:.2f} {:.2f}".format(dpi, dt_list1[i], dt_list2[i]))

    plt.figure()
    plt.plot(dpi_list, dt_list1, "b")
    plt.plot(dpi_list, dt_list2, "r")
    plt.legend(["original", "proposed"])
    plt.xlabel("DPI")
    plt.ylabel("runtime (s)")
    plt.show()
    np.save("dt1.npy", dt_list1)
    np.save("dt2.npy", dt_list2)


if __name__ == "__main__":
    main()
